#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-encode
version:              1.5.0.7
visibility:           public
id:                   uri-encode-1.5.0.7-Iwg9Uq98S6E9tjmidvCjnl
key:                  uri-encode-1.5.0.7-Iwg9Uq98S6E9tjmidvCjnl
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding
description:
    This package allows you to uri encode and uri decode
    Strings, Texts and ByteString values.

category:             Network, Web
abi:                  ba817e6e79975a138fe6533c4e159ab9
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/uri-encode-1.5.0.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uri-encode-1.5.0.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uri-encode-1.5.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-encode
hs-libraries:         HSuri-encode-1.5.0.7-Iwg9Uq98S6E9tjmidvCjnl
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-uri-2.6.4.2-2ifukYXf4pdA7CoyyYtsZ3 text-2.0.2
    utf8-string-1.0.2-BHoErC4pt0C33Qzw2Pf1X1

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

